## 0.0.21

This version includes the addition of a new scratch notebook on querying JMLR paper and two default processors.

### New Features

- New scratch notebook on querying JMLR paper added (d05c539) (Eric Ma)
- Two default processors added (408f0d0) (Eric Ma)
